#
# spec file for package terraform-provider-null
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         terraform-providers
%global repo            terraform-provider-null
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global registry        registry.terraform.io
%global namespace       hashicorp
%global providername    null

%ifarch aarch64
%define terraformarch   amd64
%endif
%ifarch ppc64
%define terraformarch   ppc64
%endif
%ifarch ppc64le
%define terraformarch   ppc64le
%endif
%ifarch s390x
%define terraformarch   s390x
%endif
%ifarch %{ix86}
%define terraformarch   i386
%endif
%ifarch x86_64
%define terraformarch   amd64
%endif

Name:           terraform-provider-null
Version:        3.1.0
Release:        2.10
Summary:        Terraform null-provider
License:        MPL-2.0
Group:          System/Management
URL:            https://github.com/terraform-providers/terraform-provider-null
Source:         %{repo}-%{version}.tar.xz
%if 0%{?suse_version}
%{go_nostrip}
%endif
%if 0%{?ubuntu_version}
BuildRequires:  debhelper
BuildRequires:  dh-golang
BuildRequires:  golang-go
BuildRequires:  libvirt-dev
BuildRequires:  pkgconfig
BuildRequires:  xz-utils
%else
Requires:       terraform >= 0.12.0
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  golang
%endif
%if 0%{?suse_version}
BuildRequires:  golang-packaging
BuildRequires:  xz
BuildRequires:  golang(API) >= 1.12
%endif
%endif
# Terraform is not available for 32bit platforms
ExcludeArch:    %ix86 %arm
%if 0%{?suse_version}
%{go_provides}
%endif

%description
This is a terraform provider that lets you use null files

%prep
%setup -q -n %{repo}-%{version}

%build
%{goprep} %{import_path}
%{gobuild} -mod=vendor ""

%install
%{goinstall}
rm -rf %{buildroot}/%{_libdir}/go/contrib
ln -s %{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}_v%{version}
install -d 755 %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}
ln -s %{_bindir}/%{name} %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}/%{name}_v%{version}

%files
%doc CHANGELOG.md README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}_v%{version}
%{_datadir}/terraform

%changelog
* Wed Mar 30 2022 Dirk Müller <dmueller@suse.com>
- exclude build for 32bit targets
* Mon Aug  2 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.1.0:
  * update to Go 1.16
  * Create CONTRIBUTING.md
  * Bump github.com/hashicorp/terraform-plugin-sdk/v2 from 2.4.2 to 2.4.3
  * Add note about document generation and registry
  * Update ID usage
  * Generate documentation
  * Move docs for new registry structure
  * Bump SDK version to 2.4.2
  * Bump actions/checkout from v2.3.3 to v2.3.4
  * move to GitHub Actions
  * Create dependabot.yml
  * Update docs link to random provider to the Registry
* Wed Nov 11 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add symbolic link to comply with new filesystem layout for local provider copies
- Define and use common Go spec file variables
* Tue Oct 20 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.0.0:
  * add .tfproto5 file for releases
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * update go version in go.mod
  * normalise naming conventions
  * Add descriptions
  * update CI
  * SDK v2.0.3
  * update provider directory layout
  * force go modules on for travis
  * restore hashibot behaviors post migration
  * Update CHANGELOG.md
  * switch to standalone sdk
  * bump terraform to v0.12.8
  * Cleanup after v2.1.2 release
  * Fix typo in resource.html.markdown
* Tue Aug 11 2020 Dirk Mueller <dmueller@suse.com>
- spec-cleaner run
* Thu Feb 20 2020 Robert Schweikert <rjschwei@suse.com>
- Setup as service
- Brush up spec file to reduce distro branching
- Create symlink for recognition by terraform
* Fri May 17 2019 <fbergmann@suse.com>
- Initial packaging of the null provider
